Exception: UCL::Error

Inherits:
StandardError
  • Object
show all
Defined in:
ext/ucl.c,
ext/ucl.c

Overview

Raised when a configuration cannot be parsed, or when the parsed tree cannot be converted to Ruby objects.